@@ -16,10 +16,11 @@ sub get_new_session {
     my ( $self, $instance ) = @_;
     my $meta = $self->associated_metaclass;
     return POE::Session->create(
-        inline_states => { _start => sub { POE::Kernel->yield('START') }, },
+        inline_states => { _start => sub { POE::Kernel->yield('STARTALL') }, },
         object_states => [
             $instance => {
-                _stop => 'STOP',
+              STARTALL => 'STARTALL',
+              _stop  => 'STOPALL',
                 map { $_ => $meta->get_state_method_name($_) }
                   map  { $_->meta->get_events }
                   grep { $_->meta->isa('MooseX::POE::Meta::Class') }
